@@ -3,12 +3,17 @@
 if [ "$(uname)" == "Darwin" ];
 then
     # for Mac OSX
+    unset AR
     unset CC
     unset CXX
     unset FC
     unset F77
     unset F90
     unset F95
+    unset LD
+    unset NM
+    unset RANLIB
+    unset STRIP
     unset MACOSX_VERSION_MIN
     unset MACOSX_DEPLOYMENT_TARGET
     unset CMAKE_OSX_DEPLOYMENT_TARGET
@@ -21,12 +26,19 @@ then
 elif [ "$(uname)" == "Linux" ]
 then
     # for Linux
+    unset AR
     unset CC
     unset CXX
     unset FC
     unset F77
     unset F90
     unset F95
+    unset LD
+    unset NM
+    unset OBJCOPY
+    unset OBJDUMP
+    unset RANLIB
+    unset STRIP
     unset CFLAGS
     unset CXXFLAGS
     unset LDFLAGS
